@@ -273,7 +273,7 @@ class FrontendBuilderABC(BuilderABC):
                                   pluginDetails: [PluginDetail]) -> None:
         """
         
-        import {TitleBarLink} from "@synerty/peek-util";
+        import {TitleBarLink} from "@synerty/peek-plugin-base-js";
 
         export const titleBarLinks :TitleBarLink = [
             {
@@ -298,8 +298,8 @@ class FrontendBuilderABC(BuilderABC):
                               badgeCount=None))
 
         contents = "// This file is auto generated, the git version is blank and .gitignored\n\n"
-        contents += "import {TitleBarLink} from '@synerty/peek-util';\n\n"
-        contents += "export const titleBarLinks :TitleBarLink[] = %s;\n" % json.dumps(
+        contents += "import { ITitleBarLink } from '@synerty/peek-plugin-base-js'\n\n"
+        contents += "export const titleBarLinks: ITitleBarLink[] = %s;\n" % json.dumps(
             links, sort_keys=True, indent=4, separators=(', ', ': '))
 
         self._writeFileIfRequired(feAppDir, 'plugin-title-bar-links.ts', contents)
